@@ -96,13 +96,15 @@ def attempt_datastructure_upgrade(didl_item):
             # The data structure should be upgraded, but there is an entry
             # missing from DIDL_NAME_TO_QUALIFIED_MS_NAME. Log this as a
             # warning.
-            _LOG.warning(
-                "DATA STRUCTURE UPGRADE FAIL. Unable to upgrade music library "
-                "data structure to music service data structure because an "
-                "entry is missing for %s in DIDL_NAME_TO_QUALIFIED_MS_NAME. "
-                "This should be reported as a bug.",
-                didl_item.__class__.__name__,
-            )
+            class_name = didl_item.__class__.__name__
+            if class_name not in ["DidlFavorite"]:
+                _LOG.warning(
+                    "DATA STRUCTURE UPGRADE FAIL. Unable to upgrade music library "
+                    "data structure to music service data structure because an "
+                    "entry is missing for %s in DIDL_NAME_TO_QUALIFIED_MS_NAME. "
+                    "This should be reported as a bug.",
+                    class_name,
+                )
             return didl_item
 
         upgraded_item = cls(
